==> localnews-base-model-1.3.0.1-sources.jar: com/bxm/localnews/common/dto/AppVersionDTO.java <==
package com.bxm.localnews.common.dto;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

/**
 * @author zhaoyadong 2018/10/22 14:56
 * @desc
 */
@ApiModel(description = "app版本信息")
public class AppVersionDTO {

    @ApiModelProperty("平台类型 1.安卓  2.ios")
    private Integer mobileType;

    @ApiModelProperty("版本号")
    private String version;

    @ApiModelProperty("更新内容")
    private String content;

    @ApiModelProperty("下载地址")
    private String downloadLink;

    @ApiModelProperty("是否强制更新 0.否 1.是")
    private Byte isForce;

    @ApiModelProperty("是否处于提包状态 0.否 1.是")
    private Byte status = 0;

    @ApiModelProperty("渠道代码")
    private String code;

    @ApiModelProperty("渠道名称")
    private String name;

    public Integer getMobileType() {
        return mobileType;
    }

    public void setMobileType(Integer mobileType) {
        this.mobileType = mobileType;
    }

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getDownloadLink() {
        return downloadLink;
    }

    public void setDownloadLink(String downloadLink) {
        this.downloadLink = downloadLink;
    }

    public Byte getIsForce() {
        return isForce;
    }

    public void setIsForce(Byte isForce) {
        this.isForce = isForce;
    }

    public Byte getStatus() {
        return status;
    }

    public void setStatus(Byte status) {
        this.status = status;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
}

==> localnews-base-model-2.0.11-sources.jar: com/bxm/localnews/common/dto/AppVersionDTO.java <==
package com.bxm.localnews.common.dto;

import java.util.Date;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

/**
 * @author zhaoyadong 2018/10/22 14:56
 * @desc
 */
@ApiModel(description = "app版本信息")
public class AppVersionDTO {

    @ApiModelProperty("平台类型 1.安卓  2.ios")
    private Integer mobileType;

    @ApiModelProperty("版本号")
    private String version;

    @ApiModelProperty("更新标题")
    private String title;

    @ApiModelProperty("更新内容")
    private String content;

    @ApiModelProperty("下载地址")
    private String downloadLink;

    @ApiModelProperty("是否强制更新 0.否 1.是")
    private Byte isForce;

    @ApiModelProperty("是否处于提包状态 0.否 1.是")
    private Byte status = 0;

    @ApiModelProperty("是否开启：0关闭 1开启")
    private Byte enable;

    @ApiModelProperty("渠道代码")
    private String code;

    @ApiModelProperty("渠道名称")
    private String name;

    @ApiModelProperty("强制更新范围")
    private String forceVersion;

    @ApiModelProperty("创建时间")
    private Date createTime;

    public Integer getMobileType() {
        return mobileType;
    }

    public void setMobileType(Integer mobileType) {
        this.mobileType = mobileType;
    }

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getDownloadLink() {
        return downloadLink;
    }

    public void setDownloadLink(String downloadLink) {
        this.downloadLink = downloadLink;
    }

    public Byte getIsForce() {
        return isForce;
    }

    public void setIsForce(Byte isForce) {
        this.isForce = isForce;
    }

    public Byte getStatus() {
        return status;
    }

    public void setStatus(Byte status) {
        this.status = status;
    }

    public Byte getEnable() {
        return enable;
    }

    public void setEnable(Byte enable) {
        this.enable = enable;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getForceVersion() {
        return forceVersion;
    }

    public void setForceVersion(String forceVersion) {
        this.forceVersion = forceVersion;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }
}
